
********************************************************************************

*Set the prices for hypothetical ones under different scenarios
global scen 20 30 40 //these three hypothetical scenarios are the same for all countries

foreach scen of global scen {
u "${data}/clean/SILC_2020_POL_2019.dta", clear

*Create the groups
qui do "${do}/Aux_Inflation_Groups.do"

*Generate the deciles (I use total disposable household income (after taxes) hy020 with HH cross-sectional weights db090)
cap isid year code hhid_n rand, sort
by year code hhid_n: keep if _n == 1

*duplicates drop year code hhid_n, force

*xtile deciles=hy020 [fw=round(db090,1)], n(10)

gquantiles deciles=hy020 [fw=round(db090,1)], n(10) by(ctry_n) xtile

*Merge with the dataset of expenditure shares (assuming consumption and income distributions are very similar)
merge m:1 ctry_n deciles using "${data}/clean/food_fuel_ALL", nogen

gen t_food=.

replace t_food=0.`scen' if ctry_n=="BG"
replace t_food=0.`scen' if ctry_n=="HR"
replace t_food=0.`scen' if ctry_n=="PL"
replace t_food=0.`scen' if ctry_n=="RO"

*One that varies by deciles (richer household have a larger epsilon while poorer ones have a more inelastic demand)
	
	gen ppp_loss_food=.
	gen hh_inc_adj_food=.
	
	forval n=1/10{
	if "`n'"<="3" local epsilon=0
	if "`n'">"3"  local epsilon=-0.25
	replace ppp_loss_food=(Foodbeverage/100)*t_food*(1+`epsilon'*(t_food/2)) if deciles==`n'
	replace hh_inc_adj_food=hy020*(1-ppp_loss_food) if deciles==`n'
	}
	
*Define households with probable positive income effects (Agricultural HHs)
gen self_emp=1 if pl040==1 | pl040==2

gen agric_hh=1 if pl111=="a" & self_emp==1 //a is agriculture, forestry and fishing

*Then generate the outputs of interest. How poverty rates changes, growth incidence curves and Gini

*International poverty line:1.9$, 3.2$, 5.5$, and 6.85$ usd per day (2017 dollars)
gen line19=1.9*365 /*int poverty line: 1.9$ per day (2017 dollars)*/
gen line32=3.2*365 /*int poverty line: 3.2$ per day (2017 dollars)*/
gen line55=5.5*365 /*int poverty line: 5.5$ per day (2017 dollars)*/
gen line68=6.85*365 /*int poverty line: 6.85$ per day (2017 dollars)*/

*How many new poor from energy and food using the poverty lines with differences across epsilons and across budget shares by deciles

foreach l in line19 line32 line55 line68 {
	gen poor`l'_food=((hh_inc_adj_food*hx010)/(icp2017*cpi2017*hx040)<=`l')
	gen poor`l'=((hy020*hx010)/(icp2017*cpi2017*hx040)<=`l')
	gen poor`l'_noSE=(poor`l'==0 & poor`l'_food==1 & hy060g==0) //how many new poor do not receive social exclusion not elsewhere classified
}

*Do aggregate for 2020 for poverty
preserve

merge 1:m year code hhid_n using "${data}/clean/SILC_2020_POL_2019.dta", nogen keep(3)

collapse (sum) poorline19 poorline32 poorline55 poorline68 poorline19_food poorline32_food poorline55_food poorline68_food poorline19_noSE poorline32_noSE poorline55_noSE poorline68_noSE (count) total_pop=rb050 [fw=round(rb050,1)], by(ctry_n)

*Gen changes in poverty rates
foreach l in line19 line32 line55 line68 {
	gen poverty_rate_`l'=(poor`l'/total_pop)*100
	gen poverty_rate_food_`l'=(poor`l'_food/total_pop)*100
	gen poverty_rate_food_`l'_noSE=(poor`l'_noSE/total_pop)*100
	gen poverty_change_food_`l'=poverty_rate_food_`l'-poverty_rate_`l'
	gen poverty_change_food_`l'_noSE=poverty_rate_food_`l'-poverty_rate_food_`l'_noSE-poverty_rate_`l'
}

*keep the variables of interest
keeporder ctry_n poverty_rate_line68 poverty_rate_food_line68 poverty_change_food_line68 poverty_change_food_line68_noSE

*Add the note for the Excel
set obs `=_N + 2'
replace ctry_n="Note: The poverty rates are constructed from household income per capita in EU-SILC 2020 and 2019 for Poland. The epsilon varies across deciles but is the same for food." in `=_N'

format %9.2fc poverty*

*Changes in poverty rates
export excel "${output}impact_inflation.xlsx", sheet("Poverty changes `scen'", replace) first(var)

restore

*Do aggregate 2020 for changes in income with varying epsilons across deciles (do it per-capita)
preserve 

merge 1:m year code hhid_n using "${data}/clean/SILC_2020_POL_2019.dta", nogen keep(3)

gen total_disp_inc_pc=(hy020*hx010)/(icp2017*cpi2017*hx040)
gen hh_inc_adj_food_pc=(hh_inc_adj_food*hx010)/(icp2017*cpi2017*hx040)

gen hh_inc_adj_food_pc_noSE=((hh_inc_adj_food-hy060g)*hx010)/(icp2017*cpi2017*hx040)

gen hh_inc_adj_food_pc_2xSE=((hh_inc_adj_food+(hy060g/2))*hx010)/(icp2017*cpi2017*hx040)

gen recipients=1 if hy060g>0 & hy060g!=.
gen non_recipients=1 if hy060g==0 & hy060g!=.

collapse (p50) total_disp_inc_pc hh_inc_adj_food_pc hh_inc_adj_food_pc_noSE hh_inc_adj_food_pc_2xSE (sum) total_inc=total_disp_inc_pc total_inc_food=hh_inc_adj_food_pc total_gmi=hy060g recipients non_recipients [fw=round(rb050,1)], by(ctry_n deciles)

drop if deciles==.

*Gen changes in income by deciles due to food
gen change_food=-(1-hh_inc_adj_food_pc/total_disp_inc_pc)*100

gen change_food_noSE=-(1-hh_inc_adj_food_pc_noSE/total_disp_inc_pc)*100

gen change_food_2xSE=-(1-hh_inc_adj_food_pc_2xSE/total_disp_inc_pc)*100

gen change_sumtotal=round(total_inc-total_inc_food,1)

egen sum_gmi=total(total_gmi), by(ctry_n)
gen target_gmi=(total_gmi/sum_gmi)*100

*The share of people that receive GMI
gen share_receive=(recipients/(non_recipients+recipients))*100

*The share of income that comes from GMI
gen share_gmi=(total_gmi/total_inc)*100

keep ctry_n deciles change* share* sum_gmi target_gmi

format %9.2fc change* 

*Add the note for the Excel
set obs `=_N + 2'
replace ctry_n="Note: The income measure is median per capita total household disposable income in EU-SILC 2020 and 2019 for Poland. The epsilon varies across deciles but is the same for food." in `=_N'

*Export it to Excel
export excel "${output}impact_inflation.xlsx", sheet("Income changes `scen'", replace) first(var)

restore

*Groups

*Do 2020 for poverty changes
mat m=J(13,4,.)
mat j=J(13,4,.)

foreach cntry in BG HR PL RO {
sum group if ctry_n=="`cntry'"
local y=r(mean)

preserve
qui merge 1:m year code hhid_n using "${data}/clean/SILC_2020_POL_2019.dta", nogen keep(3)
gen new_poor_tot=(poorline68_food==1)

keep if ctry_n=="`cntry'"

local i 1

sum poorline68 [fw=round(db090,1)], d
scalar poor1=r(mean)
sum poorline68_food [fw=round(db090,1)], d
scalar poor2=r(mean)
mat m[`i',`y']= round((poor2-poor1)*100,.01)
mat j[`i',`y']= round(poor1*100,.01)

local i=`i'+1

sum poorline68 [fw=round(db090,1)] if urban==1, d
scalar poor1=r(mean)
sum poorline68_food [fw=round(db090,1)] if urban==1, d
scalar poor2=r(mean)
mat m[`i',`y']= round((poor2-poor1)*100,.01)
mat j[`i',`y']= round(poor1*100,.01)

local i=`i'+1

sum poorline68 [fw=round(db090,1)] if urban==0, d
scalar poor1=r(mean)
sum poorline68_food [fw=round(db090,1)] if urban==0, d
scalar poor2=r(mean)
mat m[`i',`y']= round((poor2-poor1)*100,.01)
mat j[`i',`y']= round(poor1*100,.01)

local i=`i'+1

sum poorline68 [fw=round(db090,1)] if db100==1, d
scalar poor1=r(mean)
sum poorline68_food [fw=round(db090,1)] if db100==1, d
scalar poor2=r(mean)
mat m[`i',`y']= round((poor2-poor1)*100,.01)
mat j[`i',`y']= round(poor1*100,.01)

local i=`i'+1

sum poorline68 [fw=round(db090,1)] if db100==2, d
scalar poor1=r(mean)
sum poorline68_food [fw=round(db090,1)] if db100==2, d
scalar poor2=r(mean)
mat m[`i',`y']= round((poor2-poor1)*100,.01)
mat j[`i',`y']= round(poor1*100,.01)

local i=`i'+1

sum poorline68 [fw=round(db090,1)] if child_hh==1, d
scalar poor1=r(mean)
sum poorline68_food [fw=round(db090,1)] if child_hh==1, d
scalar poor2=r(mean)
mat m[`i',`y']= round((poor2-poor1)*100,.01)
mat j[`i',`y']= round(poor1*100,.01)

local i=`i'+1

sum poorline68 [fw=round(db090,1)] if pensioner_hh==1, d
scalar poor1=r(mean)
sum poorline68_food [fw=round(db090,1)] if pensioner_hh==1, d
scalar poor2=r(mean)
mat m[`i',`y']= round((poor2-poor1)*100,.01)
mat j[`i',`y']= round(poor1*100,.01)

local i=`i'+1

sum poorline68 [fw=round(db090,1)] if elderly==1 & members==1, d
scalar poor1=r(mean)
sum poorline68_food [fw=round(db090,1)] if elderly==1 & members==1, d
scalar poor2=r(mean)
mat m[`i',`y']= round((poor2-poor1)*100,.01)
mat j[`i',`y']= round(poor1*100,.01)

local i=`i'+1

sum poorline68 [fw=round(db090,1)] if femaleheaded==1, d
scalar poor1=r(mean)
sum poorline68_food [fw=round(db090,1)] if femaleheaded==1, d
scalar poor2=r(mean)
mat m[`i',`y']= round((poor2-poor1)*100,.01)
mat j[`i',`y']= round(poor1*100,.01)

local i=`i'+1

sum poorline68 [fw=round(db090,1)] if unemployed_hh==1, d
scalar poor1=r(mean)
sum poorline68_food [fw=round(db090,1)] if unemployed_hh==1, d
scalar poor2=r(mean)
mat m[`i',`y']= round((poor2-poor1)*100,.01)
mat j[`i',`y']= round(poor1*100,.01)

local i=`i'+1

sum poorline68 [fw=round(db090,1)] if members>5, d
scalar poor1=r(mean)
sum poorline68_food [fw=round(db090,1)] if members>5, d
scalar poor2=r(mean)
mat m[`i',`y']= round((poor2-poor1)*100,.01)
mat j[`i',`y']= round(poor1*100,.01)

local i=`i'+1

sum poorline68 [fw=round(db090,1)] if disabled_hh==1, d
scalar poor1=r(mean)
sum poorline68_food [fw=round(db090,1)] if disabled_hh==1, d
scalar poor2=r(mean)
mat m[`i',`y']= round((poor2-poor1)*100,.01)
mat j[`i',`y']= round(poor1*100,.01)

local i=`i'+1

sum poorline68 [fw=round(db090,1)] if socialaid_hh==1, d
scalar poor1=r(mean)
sum poorline68_food [fw=round(db090,1)] if socialaid_hh==1, d
scalar poor2=r(mean)
mat m[`i',`y']= round((poor2-poor1)*100,.01)
mat j[`i',`y']= round(poor1*100,.01)

restore
}

mat colnames m = "Bulgaria" "Croatia" "Poland" "Romania" 
mat rownames m = "All" "Urban" "Rural" "Densely populated urban" "Semi-urban" "HH with child" "HH with pensioner" "Single elderly (+64) HH" "Female-headed HH" "HH with +1 unemployed" "HH with more than 5 members" "HH with disability recipient" "HH with social aid" 

*Export it to Excel
putexcel set "${output}impact_inflation.xlsx", sheet("Poverty changes groups `scen'") modify
putexcel A1=matrix(m), names // nfor(number_d2)

putexcel A16="Note: The poverty rates are constructed from household income per capita in EU-SILC 2020 and 2019 for Poland. The epsilon varies across deciles but is the same for food."

*Export it to Excel (the baseline poverty)
mat colnames j = "Bulgaria" "Croatia" "Poland" "Romania" 
mat rownames j = "All" "Urban" "Rural" "HH with child" "HH with pensioner" "Single elderly (+64) HH" "Female-headed HH" "HH with +1 unemployed" "HH with more than 5 members" "HH with disability recipient" "HH with social aid"

putexcel set "${output}impact_inflation.xlsx", sheet("Poverty baseline groups") modify
putexcel A1=matrix(j), names // nfor(number_d2)

putexcel A14="Note: The poverty rates are constructed from household income per capita in EU-SILC 2020 and 2019 for Poland. The epsilon varies across deciles but is the same for food."

*Do 2020 for changes in income with varying epsilons across deciles
mat m=J(13,4,.)

foreach cntry in BG HR PL RO {
sum group if ctry_n=="`cntry'"
local y=r(mean)

preserve
merge 1:m year code hhid_n using "${data}/clean/SILC_2020_POL_2019.dta", nogen keep(3)

gen total_disp_inc_pc=hy020/hx040
gen hh_inc_adj_food_pc=hh_inc_adj_food/hx040

gen change_food=-(1-hh_inc_adj_food_pc/total_disp_inc_pc)*100

keep if ctry_n=="`cntry'"

foreach var in change_food{

local i 1

sum `var' [fw=round(rb050,1)], d
mat m[`i',`y']= round(r(mean),.01)

local i=`i'+1

sum `var' [fw=round(rb050,1)] if urban==1, d
mat m[`i',`y']= round(r(mean),.01)

local i=`i'+1

sum `var' [fw=round(rb050,1)] if urban==0, d
mat m[`i',`y']= round(r(mean),.01)

local i=`i'+1

sum `var' [fw=round(rb050,1)] if db100==1, d
mat m[`i',`y']= round(r(mean),.01)

local i=`i'+1

sum `var' [fw=round(rb050,1)] if db100==2, d
mat m[`i',`y']= round(r(mean),.01)

local i=`i'+1

sum `var' [fw=round(rb050,1)] if child_hh==1, d
mat m[`i',`y']= round(r(mean),.01)

local i=`i'+1

sum `var' [fw=round(rb050,1)] if pensioner_hh==1, d
mat m[`i',`y']= round(r(mean),.01)

local i=`i'+1

sum `var' [fw=round(rb050,1)] if elderly==1 & members==1, d
mat m[`i',`y']= round(r(mean),.01)

local i=`i'+1
sum `var' [fw=round(rb050,1)] if femaleheaded==1, d
mat m[`i',`y']= round(r(mean),.01)

local i=`i'+1

sum `var' [fw=round(rb050,1)] if unemployed_hh==1, d
mat m[`i',`y']= round(r(mean),.01)

local i=`i'+1

sum `var' [fw=round(rb050,1)] if members>5, d
mat m[`i',`y']= round(r(mean),.01)

local i=`i'+1

sum `var' [fw=round(rb050,1)] if disabled_hh==1, d
mat m[`i',`y']= round(r(mean),.01)

local i=`i'+1

sum `var' [fw=round(rb050,1)] if socialaid_hh==1, d
mat m[`i',`y']= round(r(mean),.01)

restore
}
}

mat colnames m = "Bulgaria" "Croatia" "Poland" "Romania" 
mat rownames m = "All" "Urban" "Rural" "Densely populated urban" "Semi-urban" "HH with child" "HH with pensioner" "Single elderly (+64) HH" "Female-headed HH" "HH with +1 unemployed" "HH with more than 5 members" "HH with disability recipient" "HH with social aid" 

*Export it to Excel
putexcel set "${output}impact_inflation.xlsx", sheet("Income changes groups `scen'") modify
putexcel A1=matrix(m), names // nfor(number_d2)

putexcel A16="Note: The income measure is income adult equivalent in EU-SILC 2020 and 2019 for Poland. The epsilon varies across deciles but is the same for food."

*Do 2020 for changes in income with mitigation and varying epsilons across deciles
mat d=J(13,4,.)

foreach cntry in BG HR PL RO {
sum group if ctry_n=="`cntry'"
local y=r(mean)

preserve
merge 1:m year code hhid_n using "${data}/clean/SILC_2020_POL_2019.dta", nogen keep(3)

gen total_disp_inc_pc=hy020/hx040
gen hh_inc_adj_food_pc=hh_inc_adj_food/hx040
gen SA_PC=hy060g/hx040

gen change_food=-(1-hh_inc_adj_food_pc/total_disp_inc_pc)*100
gen change_food_2xSE=-(1-((hh_inc_adj_food_pc+(SA_PC/2))/total_disp_inc_pc))*100

keep if ctry_n=="`cntry'"

foreach var in change_food_2xSE{

local i 1

sum `var' [fw=round(rb050,1)], d
mat d[`i',`y']= round(r(mean),.01)

local i=`i'+1

sum `var' [fw=round(rb050,1)] if urban==1, d
mat d[`i',`y']= round(r(mean),.01)

local i=`i'+1

sum `var' [fw=round(rb050,1)] if urban==0, d
mat d[`i',`y']= round(r(mean),.01)

local i=`i'+1

sum `var' [fw=round(rb050,1)] if db100==1, d
mat d[`i',`y']= round(r(mean),.01)

local i=`i'+1

sum `var' [fw=round(rb050,1)] if db100==2, d
mat d[`i',`y']= round(r(mean),.01)

local i=`i'+1

sum `var' [fw=round(rb050,1)] if child_hh==1, d
mat d[`i',`y']= round(r(mean),.01)

local i=`i'+1

sum `var' [fw=round(rb050,1)] if pensioner_hh==1, d
mat d[`i',`y']= round(r(mean),.01)

local i=`i'+1

sum `var' [fw=round(rb050,1)] if elderly==1 & members==1, d
mat d[`i',`y']= round(r(mean),.01)

local i=`i'+1
sum `var' [fw=round(rb050,1)] if femaleheaded==1, d
mat d[`i',`y']= round(r(mean),.01)

local i=`i'+1

sum `var' [fw=round(rb050,1)] if unemployed_hh==1, d
mat d[`i',`y']= round(r(mean),.01)

local i=`i'+1

sum `var' [fw=round(rb050,1)] if members>5, d
mat d[`i',`y']= round(r(mean),.01)

local i=`i'+1

sum `var' [fw=round(rb050,1)] if disabled_hh==1, d
mat d[`i',`y']= round(r(mean),.01)

local i=`i'+1

sum `var' [fw=round(rb050,1)] if socialaid_hh==1, d
mat d[`i',`y']= round(r(mean),.01)

restore
}
}

mat colnames d = "Bulgaria" "Croatia" "Poland" "Romania" 
mat rownames d = "All" "Urban" "Rural" "Densely populated urban" "Semi-urban" "HH with child" "HH with pensioner" "Single elderly (+64) HH" "Female-headed HH" "HH with +1 unemployed" "HH with more than 5 members" "HH with disability recipient" "HH with social aid" 

*Export it to Excel
putexcel set "${output}impact_inflation.xlsx", sheet("Inc changes GMI groups `scen'") modify
putexcel A1=matrix(d), names // nfor(number_d2)

putexcel A16="Note: The income measure is income adult equivalent in EU-SILC 2020 and 2019 for Poland. The epsilon varies across deciles but is the same for food."

*Groups by NUTS1

*Do 2020 for poverty changes
mat m=J(3,14,.)

local y 0
foreach cntry in BG3 BG4 HR0 PL2 PL4 PL5 PL6 PL7 PL8 PL9 RO1 RO2 RO3 RO4 {
local y=`y'+1

preserve
qui merge 1:m year code hhid_n using "${data}/clean/SILC_2020_POL_2019.dta", nogen keep(3)
gen new_poor_tot=(poorline68_food==1)

gen total_disp_inc_pc=hy020/hx040
gen hh_inc_adj_food_pc=hh_inc_adj_food/hx040

gen change_food=-(1-hh_inc_adj_food_pc/total_disp_inc_pc)*100


keep if db040=="`cntry'"

sum poorline68 [fw=round(db090,1)], d
scalar poor1=r(mean)
sum poorline68_food [fw=round(db090,1)], d
scalar poor2=r(mean)
mat m[1,`y']= round(poor1*100,.01)
mat m[2,`y']= round((poor2-poor1)*100,.01)

sum change_food [fw=round(rb050,1)], d
mat m[3,`y']= round(r(mean),.01)

restore
}

mat colnames m = "North and east BG" "South west and south central BG" "HR" "South PL" "North west PL" "South west PL" "North PL" "Central PL" "East PL" "Masovian PL" "One RO" "Two RO" "Three RO" "Four RO" 
mat rownames m = "Baseline Poverty" "Poverty changes" "Income Changes"

*Export it to Excel
putexcel set "${output}impact_inflation.xlsx", sheet("Changes NUTS `scen'") modify
putexcel A1=matrix(m), names // nfor(number_d2)

putexcel A6="Note: The poverty rates are constructed from household income per capita in EU-SILC 2020 and 2019 for Poland. The epsilon varies across deciles but is the same for food. The income measure is income adult equivalent in EU-SILC 2020 and 2019 for Poland. The epsilon varies across deciles but is the same for food."

*Gini analysis is income adult equivalent by countries with varying epsilons across deciles
preserve

merge 1:m year code hhid_n using "${data}/clean/SILC_2020_POL_2019.dta", nogen keep(3)

*For the equivalized individual income
gen double inc_equi=(hy020/hx050) //*hx010/cpi2017
gen double inc_equi_food=(hh_inc_adj_food/hx050) //*hx010/cpi2017

matrix C=J(2,4,0)

foreach cntry in BG HR PL RO {
sum group if ctry_n=="`cntry'"
local y=r(mean)

fastgini inc_equi [fw=round(rb050,1)] if ctry_n=="`cntry'"
scalar gini_`ctry'=r(gini)
matrix C[1,`y'] = gini_`ctry'

fastgini inc_equi_food [fw=round(rb050,1)] if ctry_n=="`cntry'"
scalar gini_`ctry'_food=r(gini)
matrix C[2,`y'] = gini_`ctry'_food


}

*Export it to Excel
mat rownames C="Gini" "Gini adjusted for food"
mat colnames C="Bulgaria" "Croatia" "Poland" "Romania"

putexcel set "${output}impact_inflation.xlsx", sheet("Gini changes `scen'") modify
putexcel A1=matrix(C), names nfor(number_d2)

putexcel A6="Note: The income measure is income adult equivalent in EU-SILC 2020 and 2019 for Poland. The epsilon varies across deciles but is the same for food."

restore
}
