*Groups
********************************************************************************

 *Gender
recode rb090 (2=1)(1=0), gen(female)
gen male = (female==0)

* Age
gen age=rx020 /*age at the end of the income reference period*/
replace age=rx010 if age==.

* Labor force status
ta pl031,m
gen lfstat=. 
			 replace lfstat=1 if (pl031==1| pl031==2|pl031==3|pl031==4) & year>=2009 // employee working full-time, employee working part-time, self-employed full time, self-employed part time
             replace lfstat=2 if pl031==5 & year>=2009 // unemployed
             replace lfstat=3 if pl031==7 & year>=2009 // retired
             replace lfstat=4 if (pl031==8|pl031==9|pl031==10|pl031==11) & year>=2009 // long-term disability, military/community or service, care responsibilities, other inactive person
             replace lfstat=5 if pl031 ==6  & year>=2009 // student
	
replace lfstat=. if age<=15
   recode lfstat (1=1)(2=3)(3=4)(4=5)(5=6)(.=.), gen(lfstat1)
                replace lfstat1=2 if (pl031==3 | pl031==4) & year>=2009
				label define lfstat1 1 "Employed" 2 "Self-employed" 3"Unemployed" 4"Retired" 5"Inactive" 6"Student"
                label values lfstat1 lfstat1
				
gen unemployed=(lfstat1==3)

*Urban
recode db100 (1 2=1) (3=0), gen(urban)
tab urban 
label var urban "Urban"	

* Female headed

* Household id

egen hhid_year_psu = group(hhid_n year_n db060) //In Croatia all values of db062 are missing, so I use db060 instead
codebook hhid_year_psu
duplicates report hhid_year_psu

* Household head (=1 if head, =0 otherwise)
set seed 246279
gen rand = runiform()
cap isid hhid_year_psu rb030 year rand, sort missok
by hhid_year_psu: g i=_n
cap drop hhead
gen hhead=(i==1)
drop i	
tab hhead	

gen femalehead = (female>0 & hhead==1)
tab femalehead

cap drop femaleheaded
bys hhid_year_psu: egen femaleheaded=max(femalehead)

*HH with at least one unemployed
bys hhid_year_psu: egen unemployed_hh=max(unemployed)
sum unemployed_hh

*Single elderly household
gen elderly=(age>64)
gen members=hx040

gen single_elderly=0
replace single_elderly=1 if elderly==1 & members==1
tab single_elderly
bys hhid_year_psu: egen single_elderly_hh=max(single_elderly)
sum single_elderly_hh

*HH with child
gen child=(age<15)
bys hhid_year_psu: egen child_hh=max(child)
sum child_hh

*HH with +5 members
gen hh_5members = 0
replace hh_5members=1 if members>4
tab hh_5members

*HH with disabled
gen disabled = (py130g>0)
tab disabled, m
bys hhid_year_psu: egen disabled_hh=max(disabled)
tab disabled_hh

*HH with pensioner
gen pensioner = (py100g>0)
tab pensioner, m 
replace pensioner = 0 if missing(py100g)
cap drop pensioner_hh
bys hhid_year_psu: egen pensioner_hh=max(pensioner)
tab pensioner_hh

*HH with social aid (not the same as in HBS)
gen socialaid = 0

global sps py090g py100g py110g py120g py130g py140g
foreach var in $sps{
	replace socialaid=1 if `var'>0
}
tab socialaid 
bys hhid_year_psu: egen socialaid_hh=max(socialaid)
tab socialaid

*Countries
egen group=group(ctry_n)

*Create the main groups for the analysis of income and poverty changes
gen group1=1
gen group2=(urban==1)
gen group3=(urban==0)
gen group4=(child_hh==1)
gen group5=(pensioner_hh==1)
gen group6=(single_elderly==1)
gen group7=(femaleheaded==1)
gen group8=(unemployed_hh==1)
gen group9=(hh_5members==1)
gen group10=(disabled_hh==1)
gen group11=(socialaid_hh==1)


		label define group 1 "All" 1 "Urban" 2 "Rural" 3 "HH with child" 4 "HH with pensioner" 5 "Single elderly (+64) HH" 6 "Female-headed HH" 7 "HH with +1 unemployed" 8 "HH with more than 5 members" 9 "HH with disability recipient" 10 "HH with social aid" 
	    *label values group group
